# student

Source: [base_schema_pkg/sub/student.k](https://url/to/source_code/base_schema_pkg/sub/student.k)

## Schema Student

Student is the person with a grade

### Base Schema
[@base_schema_pkg.base.Person](../base/doc_person_en#schema-person)

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**grade**<br />the current grade that the student is in.|int|Undefined|**required**|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
